======
Future
======

``multigtfs`` is production ready. It is likely that future releases will be
driven by maintenance needs rather than the release of interesting new
features.

Maintenance includes:

- Keeping up with `Django releases`_
- Keeping up with `GTFS spec updates`_

Ideas for future features include:

- Validating the feed against Google's requirements
- Creating a difference report against two feeds

See the `issues list`_ for more details.

.. _`Django releases`: https://www.djangoproject.com/download/
.. _`GTFS spec updates`: https://developers.google.com/transit/gtfs/changes#RevisionHistory
.. _`issues list`: https://github.com/tulsawebdevs/django-multi-gtfs/issues?state=open
